#!/usr/bin/python3

"""
This script creates a latex document containing a big table with
detailed results for all students. Each table cell is color coded
based on the correctness in percents for the that question and
student.

Input to the program is a txt file containing a subset of the output
of the script getGrades.py, namely the lines from the detailed listing
(the last listing in the output of getGrades.py).

If data is generated via other means: the assumed structure of a line
is

StudentID grade pointsInTotal percentQ1 percentQ2 percentQ3........

Call the script like this:

  showdetails.py resultDetails.txt

The output is a latex file, which should then be compiled as usual to pdf.

"""

import sys

startOfLatexDoc = r"""
\documentclass[10pt]{article}

\usepackage[landscape,margin=1cm]{geometry}
\usepackage{longtable}
\usepackage[table]{xcolor} % the option loads (and supports with xcolor
                           % features) the colortbl package
\usepackage[utf8]{inputenc}
\setlength{\parindent}{0em}
\setlength{\parskip}{1ex}

\begin{document}

\small

\setlength{\tabcolsep}{1.5pt}
\setlength{\arrayrulewidth}{1.5pt}

"""

endOfLatexDoc = r"""
\end{longtable}
\end{document}
"""

def colorNumberCell(percent):
  p = float(percent)*100
  color = r"green!%.0f!red" % p
  cellstring = r"%.2f\cellcolor{%s}" % (percent,color)
  return cellstring

def processLine(line):
  lineparts = line.split()
  # studentID:
  tablelineparts = [lineparts[0]]
  for i in range(3,noOfQuestions + 3):
    # percents per Q:
    tablelineparts.append(r"&" + colorNumberCell(float(lineparts[i])))
  # pts and grade:
  tablelineparts.append(r"&%.2f&%s\\" % (float(lineparts[2]),lineparts[1]))
  return "".join(tablelineparts)

# find the number of questions from the line length
with open(sys.argv[1], 'r') as f:
  firstline = f.readline()
  noOfQuestions = len(firstline.split()) - 3

noOfFiveGroups = noOfQuestions // 5
noOfRestGroups = noOfQuestions  % 5

answercolums = r"|ccccc"*noOfFiveGroups + r"|" + r"c"*noOfRestGroups + r"|" if noOfRestGroups else r""
tableSpecs =  r"\begin{longtable}{" + r"l" + answercolums + r"rc|}"

headingRow = r"&" + r"&".join([str(i) for i in range(1,noOfQuestions+1)]) + r"&&\\"

print(startOfLatexDoc)
print(tableSpecs)
print(headingRow)
with open(sys.argv[1], 'r') as f:
  for line in f:
    print(processLine(line))
print(endOfLatexDoc)
